@@ -6,16 +6,15 @@ import pyvcloud.vcd.client as vcd_client
 
 from container_service_extension.client.de_cluster import DECluster
 from container_service_extension.client.de_cluster_native import DEClusterNative  # noqa: E501
-from container_service_extension.client.de_cluster_tkg import DEClusterTKG
+from container_service_extension.client.de_cluster_tkg_s import DEClusterTKGS
 from container_service_extension.client.legacy_cluster_native import LegacyClusterNative  # noqa: E501
-from container_service_extension.shared_constants import ClusterEntityKind
-from container_service_extension.shared_constants import CSE_SERVER_RUNTIMES
+from container_service_extension.common.constants.shared_constants import ClusterEntityKind  # noqa: E501
 
 
 class Cluster:
     """Returns the cluster class as determined by API version."""
 
-    def __new__(cls, client: vcd_client, k8_runtime=None):
+    def __new__(cls, client: vcd_client.Client, k8_runtime=None):
         """Create the right cluster class for the negotiated API version.
 
         In case of ApiVersion.VERSION_35, return specific instance if the
@@ -26,7 +25,6 @@ class Cluster:
         list_clusters()
 
         :param pyvcloud.vcd.client client: vcd client
-        :param str k8_runtime:
 
         :return: instance of version specific client side cluster
         """
@@ -34,9 +32,9 @@ class Cluster:
         if float(api_version) < float(vcd_client.ApiVersion.VERSION_35.value):   # noqa: E501
             return LegacyClusterNative(client)
         elif float(api_version) >= float(vcd_client.ApiVersion.VERSION_35.value):  # noqa: E501
-            if k8_runtime in CSE_SERVER_RUNTIMES:
+            if k8_runtime == ClusterEntityKind.NATIVE.value or k8_runtime == ClusterEntityKind.TKG_PLUS.value:  # noqa: E501
                 return DEClusterNative(client)
             elif k8_runtime == ClusterEntityKind.TKG_S.value:
-                return DEClusterTKG(client)
+                return DEClusterTKGS(client)
             else:
                 return DECluster(client)
