@@ -14,13 +14,14 @@ import container_service_extension.client.constants as cli_constants
 from container_service_extension.client.de_cluster_native import DEClusterNative  # noqa: E501
 import container_service_extension.client.sample_generator as client_sample_generator  # noqa: E501
 import container_service_extension.client.utils as client_utils
-from container_service_extension.exceptions import CseResponseError
-from container_service_extension.exceptions import CseServerNotRunningError
-from container_service_extension.logger import CLIENT_LOGGER
-from container_service_extension.minor_error_codes import MinorErrorCode
-from container_service_extension.server_constants import LocalTemplateKey
-import container_service_extension.shared_constants as shared_constants
-import container_service_extension.utils as utils
+from container_service_extension.common.constants.server_constants import LocalTemplateKey  # noqa: E501
+import container_service_extension.common.constants.shared_constants as shared_constants  # noqa: E501
+import container_service_extension.common.utils.core_utils as utils
+from container_service_extension.exception.exceptions import CseResponseError
+from container_service_extension.exception.exceptions import CseServerNotRunningError  # noqa: E501
+from container_service_extension.exception.minor_error_codes import MinorErrorCode  # noqa: E501
+from container_service_extension.logging.logger import CLIENT_LOGGER
+import container_service_extension.rde.utils as def_utils
 
 
 @click.group(name='cluster', cls=cmd_filter.GroupCommandFilter,
@@ -130,7 +131,7 @@ Examples
     default=None,
     required=False,
     metavar='CLUSTER_ID',
-    help="ID of the cluster whose cluster config has to be obtained;"
+    help="ID of the cluster which needs to be deleted;"
          "Supported only for CSE api version >= 35."
          "ID gets precedence over cluster name.")
 def cluster_delete(ctx, name, vdc, org, k8_runtime=None, cluster_id=None):
@@ -144,7 +145,7 @@ Example
 \b
     vcd cse cluster delete --id urn:vcloud:entity:cse:nativeCluster:1.0.0:0632c7c7-a613-427c-b4fc-9f1247da5561
         Delete cluster with cluster ID 'urn:vcloud:entity:cse:nativeCluster:1.0.0:0632c7c7-a613-427c-b4fc-9f1247da5561'.
-        (--id option is suported only applicable for api version >= 35)
+        (--id option is supported only applicable for api version >= 35)
     """  # noqa: E501
     CLIENT_LOGGER.debug(f'Executing command: {ctx.command_path}')
     try:
@@ -156,7 +157,8 @@ Example
 
         client = ctx.obj['client']
         if client_utils.is_cli_for_tkg_s_only():
-            if k8_runtime in shared_constants.CSE_SERVER_RUNTIMES:
+            if k8_runtime in [shared_constants.ClusterEntityKind.NATIVE.value,
+                              shared_constants.ClusterEntityKind.TKG_PLUS.value]:  # noqa: E501
                 # Cannot run the command as cse cli is enabled only for native
                 raise CseServerNotRunningError()
             k8_runtime = shared_constants.ClusterEntityKind.TKG_S.value
@@ -166,6 +168,7 @@ Example
         result = cluster.delete_cluster(name, cluster_id=cluster_id,
                                         org=org, vdc=vdc)
         if len(result) == 0:
+            # TODO(CLI): Update message to use vcd task wait instead
             click.secho(f"Delete cluster operation has been initiated on "
                         f"{name}, please check the status using"
                         f" 'vcd cse cluster info {name}'.", fg='yellow')
@@ -340,8 +343,8 @@ Examples
         CLIENT_LOGGER.debug(result)
     except CseResponseError as e:
         minor_error_code_to_error_message = {
-            MinorErrorCode.REQUEST_KEY_NETWORK_NAME_MISSING: 'Missing option "-n" / "--network".', # noqa: E501
-            MinorErrorCode.REQUEST_KEY_NETWORK_NAME_INVALID: 'Invalid or missing value for option "-n" / "--network".' # noqa: E501
+            MinorErrorCode.REQUEST_KEY_NETWORK_NAME_MISSING: 'Missing option "-n" / "--network".',  # noqa: E501
+            MinorErrorCode.REQUEST_KEY_NETWORK_NAME_INVALID: 'Invalid or missing value for option "-n" / "--network".'  # noqa: E501
         }
         e.error_message = \
             minor_error_code_to_error_message.get(
@@ -494,8 +497,8 @@ Examples
         CLIENT_LOGGER.debug(result)
     except CseResponseError as e:
         minor_error_code_to_error_message = {
-            MinorErrorCode.REQUEST_KEY_NETWORK_NAME_MISSING: 'Missing option "-n" / "--network".', # noqa: E501
-            MinorErrorCode.REQUEST_KEY_NETWORK_NAME_INVALID: 'Invalid or missing value for option "-n" / "--network".' # noqa: E501
+            MinorErrorCode.REQUEST_KEY_NETWORK_NAME_MISSING: 'Missing option "-n" / "--network".',  # noqa: E501
+            MinorErrorCode.REQUEST_KEY_NETWORK_NAME_INVALID: 'Invalid or missing value for option "-n" / "--network".'  # noqa: E501
         }
         e.error_message = \
             minor_error_code_to_error_message.get(
@@ -510,7 +513,12 @@ Examples
 @cluster_group.command('apply',
                        short_help='apply a configuration to a cluster resource'
                                   ' by filename. The resource will be created '
-                                  'if it does not exist.')
+                                  'if it does not exist. (The command can be '
+                                  'used to create the cluster, scale-up/down '
+                                  'worker count, scale-up NFS nodes, upgrade '
+                                  'the cluster to a new K8s version. Note '
+                                  'that for api_version <36.0, upgrades are '
+                                  'not supported with this command.)')
 @click.pass_context
 @click.argument(
     'cluster_config_file_path',
@@ -539,7 +547,7 @@ Examples
     'k8_runtime',
     is_flag=True,
     flag_value=shared_constants.ClusterEntityKind.TKG_S.value,
-    help="should be used with --sample, this flag generates sample yaml for k8 runtime: TKG service"  # noqa: E501
+    help="should be used with --sample, this flag generates sample yaml for k8 runtime: TKG"  # noqa: E501
 )
 @click.option(
     '-p',
@@ -550,15 +558,6 @@ Examples
     flag_value=shared_constants.ClusterEntityKind.TKG_PLUS.value,
     help="should be used with --sample, this flag generates sample yaml for k8 runtime: TKG+"  # noqa: E501
 )
-@click.option(
-    '-t',
-    '--tkg',
-    'k8_runtime',
-    is_flag=True,
-    hidden=not utils.is_environment_variable_enabled(cli_constants.ENV_CSE_TKG_M_ENABLED),  # noqa: E501
-    flag_value=shared_constants.ClusterEntityKind.TKG_M.value,
-    help="should be used with --sample, this flag generates sample yaml for k8 runtime: TKGm"  # noqa: E501
-)
 @click.option(
     '-o',
     '--output',
@@ -599,38 +598,43 @@ def apply(ctx, cluster_config_file_path, generate_sample_config, k8_runtime, out
             CLIENT_LOGGER.error(msg)
             raise Exception(msg)
 
+        client = ctx.obj['client']
         if generate_sample_config:
-            tkg_plus_env_enabled = utils.is_environment_variable_enabled(cli_constants.ENV_CSE_TKG_PLUS_ENABLED)  # noqa: E501
-            tkg_m_env_enabled = utils.is_environment_variable_enabled(cli_constants.ENV_CSE_TKG_M_ENABLED)  # noqa: E501
             if not k8_runtime:
                 console_message_printer.general_no_color(ctx.get_help())
-                msg = "with option --sample you must specify one of the options: --native or --tkg-s"  # noqa: E501
-                if tkg_plus_env_enabled:
+                msg = "with option --sample you must specify either of options: --native or --tkg-s"  # noqa: E501
+                if utils.is_environment_variable_enabled(cli_constants.ENV_CSE_TKG_PLUS_ENABLED):  # noqa: E501
                     msg += " or --tkg-plus"
-                if tkg_m_env_enabled:
-                    msg += " or --tkg"
                 CLIENT_LOGGER.error(msg)
                 raise Exception(msg)
-            if k8_runtime == shared_constants.ClusterEntityKind.TKG_PLUS.value \
-                    and not tkg_plus_env_enabled:  # noqa: E501
+            elif k8_runtime == shared_constants.ClusterEntityKind.TKG_PLUS.value \
+                    and not utils.is_environment_variable_enabled(cli_constants.ENV_CSE_TKG_PLUS_ENABLED):  # noqa: E501
                 raise Exception(f"{shared_constants.ClusterEntityKind.TKG_PLUS.value} not enabled")  # noqa: E501
-            if k8_runtime == shared_constants.ClusterEntityKind.TKG_M.value \
-                    and not tkg_m_env_enabled:  # noqa: E501
-                raise Exception(f"{shared_constants.ClusterEntityKind.TKG_M.value} not enabled")  # noqa: E501
+            else:
+                # since apply command is not exposed when CSE server is not
+                # running, it is safe to get the server_rde_version from
+                # VCD API version as VCD API version will be the supported by
+                # CSE server.
+                server_rde_version = \
+                    def_utils.get_runtime_rde_version_by_vcd_api_version(
+                        client.get_api_version())
+                sample_cluster_config = \
+                    client_sample_generator.get_sample_cluster_configuration(
+                        output=output,
+                        k8_runtime=k8_runtime,
+                        server_rde_in_use=server_rde_version)
+                console_message_printer.general_no_color(sample_cluster_config)
+                return
 
-            sample_cluster_config = client_sample_generator.get_sample_cluster_configuration(output=output, k8_runtime=k8_runtime)  # noqa: E501
-            console_message_printer.general_no_color(sample_cluster_config)
-            return
-
-        client = ctx.obj['client']
         with open(cluster_config_file_path) as f:
-            cluster_config = yaml.safe_load(f) or {}
+            cluster_config_map = yaml.safe_load(f) or {}
 
-        k8_runtime = cluster_config.get('kind')
+        k8_runtime = cluster_config_map.get('kind')
         if not k8_runtime:
             raise Exception("Cluster kind missing from the spec.")
         if client_utils.is_cli_for_tkg_s_only():
-            if k8_runtime in shared_constants.CSE_SERVER_RUNTIMES:
+            if k8_runtime in [shared_constants.ClusterEntityKind.NATIVE.value,
+                              shared_constants.ClusterEntityKind.TKG_PLUS.value]:  # noqa: E501
                 # Cannot run the command as cse cli is enabled only for native
                 raise CseServerNotRunningError()
             k8_runtime = shared_constants.ClusterEntityKind.TKG_S.value
@@ -640,8 +644,8 @@ def apply(ctx, cluster_config_file_path, generate_sample_config, k8_runtime, out
             if not org:
                 org_name = ctx.obj['profiles'].get('org_in_use')
 
-        cluster = Cluster(client, k8_runtime=cluster_config.get('kind'))  # noqa: E501
-        result = cluster.apply(cluster_config, cluster_id=cluster_id,
+        cluster = Cluster(client, k8_runtime=cluster_config_map.get('kind'))
+        result = cluster.apply(cluster_config_map, cluster_id=cluster_id,
                                org=org_name)
         stdout(result, ctx)
         CLIENT_LOGGER.debug(result)
@@ -675,6 +679,7 @@ def apply(ctx, cluster_config_file_path, generate_sample_config, k8_runtime, out
 def delete_nfs(ctx, cluster_name, node_name, vdc, org):
     """Remove nfs node in a cluster that uses native Kubernetes provider."""
     CLIENT_LOGGER.debug(f'Executing command: {ctx.command_path}')
+    # NOTE: command is exposed only if cli is enabled for native clusters
     try:
         client_utils.cse_restore_session(ctx)
         client = ctx.obj['client']
@@ -731,10 +736,12 @@ Examples
     (Supported only for vcd api version >= 35)
     """
     CLIENT_LOGGER.debug(f'Executing command: {ctx.command_path}')
+    # NOTE: Command is exposed only if CLI is enabled for native clusters
     try:
         client_utils.cse_restore_session(ctx)
         if client_utils.is_cli_for_tkg_s_only():
-            if k8_runtime in shared_constants.CSE_SERVER_RUNTIMES:
+            if k8_runtime in [shared_constants.ClusterEntityKind.NATIVE.value,
+                              shared_constants.ClusterEntityKind.TKG_PLUS.value]:  # noqa: E501
                 # Cannot run the command as cse cli is enabled only for native
                 raise CseServerNotRunningError()
             k8_runtime = shared_constants.ClusterEntityKind.TKG_S.value
@@ -752,7 +759,7 @@ Examples
                 'Template Revision': template[LocalTemplateKey.REVISION],
                 'Kubernetes': template[LocalTemplateKey.KUBERNETES_VERSION],
                 'Docker-CE': template[LocalTemplateKey.DOCKER_VERSION],
-                'CNI': f"{template[LocalTemplateKey.CNI]} {template[LocalTemplateKey.CNI_VERSION]}" # noqa: E501
+                'CNI': f"{template[LocalTemplateKey.CNI]} {template[LocalTemplateKey.CNI_VERSION]}"  # noqa: E501
             })
 
         if not templates:
@@ -812,10 +819,12 @@ Example
         Affected software: Docker-CE, Kubernetes, CNI
     """
     CLIENT_LOGGER.debug(f'Executing command: {ctx.command_path}')
+    # NOTE: Command is exposed only if CLI is enabled for native
     try:
         client_utils.cse_restore_session(ctx)
         if client_utils.is_cli_for_tkg_s_only():
-            if k8_runtime in shared_constants.CSE_SERVER_RUNTIMES:
+            if k8_runtime in [shared_constants.ClusterEntityKind.NATIVE.value,
+                              shared_constants.ClusterEntityKind.TKG_PLUS.value]:  # noqa: E501
                 # Cannot run the command as cse cli is enabled only for native
                 raise CseServerNotRunningError()
             k8_runtime = shared_constants.ClusterEntityKind.TKG_S.value
@@ -869,8 +878,8 @@ Example
     default=None,
     required=False,
     metavar='CLUSTER_ID',
-    help="ID of the cluster whose cluster config has to be obtained."
-         "Supported only for CSE api version >= 35."
+    help="ID of the cluster whose cluster config has to be obtained;"
+         "supported only for CSE api version >= 35."
          "ID gets precedence over cluster name.")
 def cluster_config(ctx, name, vdc, org, k8_runtime=None, cluster_id=None):
     """Display cluster configuration.
@@ -896,7 +905,8 @@ Examples:
                             "Note that '--id' flag is applicable for API versions >= 35 only.")  # noqa: E501
         client_utils.cse_restore_session(ctx)
         if client_utils.is_cli_for_tkg_s_only():
-            if k8_runtime in shared_constants.CSE_SERVER_RUNTIMES:
+            if k8_runtime in [shared_constants.ClusterEntityKind.NATIVE.value,
+                              shared_constants.ClusterEntityKind.TKG_PLUS.value]:  # noqa: E501
                 # Cannot run the command as cse cli is enabled only for native
                 raise CseServerNotRunningError()
             k8_runtime = shared_constants.ClusterEntityKind.TKG_S.value
@@ -904,15 +914,17 @@ Examples:
         cluster = Cluster(client, k8_runtime=k8_runtime)
         if not client.is_sysadmin() and org is None:
             org = ctx.obj['profiles'].get('org_in_use')
-        cluster_config = \
-            cluster.get_cluster_config(name, cluster_id=cluster_id,
-                                       vdc=vdc, org=org) \
-            .get(shared_constants.RESPONSE_MESSAGE_KEY)  # noqa: E501
+        ret_val = cluster.get_cluster_config(
+            name,
+            cluster_id=cluster_id,
+            vdc=vdc,
+            org=org
+        ).get(shared_constants.RESPONSE_MESSAGE_KEY)
         if os.name == 'nt':
-            cluster_config = str.replace(cluster_config, '\n', '\r\n')
+            ret_val = str.replace(ret_val, '\n', '\r\n')
 
-        click.secho(cluster_config)
-        CLIENT_LOGGER.debug(cluster_config)
+        click.secho(ret_val)
+        CLIENT_LOGGER.debug(ret_val)
     except Exception as e:
         stderr(e, ctx)
         CLIENT_LOGGER.error(str(e))
@@ -953,7 +965,7 @@ Examples:
     default=None,
     required=False,
     metavar='CLUSTER_ID',
-    help="ID of the cluster whose cluster config has to be obtained;"
+    help="ID of the cluster whose info has to be obtained;"
          "Supported only for CSE api version >=35. "
          "ID gets precedence over cluster name.")
 def cluster_info(ctx, name, org, vdc, k8_runtime=None, cluster_id=None):
@@ -978,12 +990,15 @@ Example
                             "Note that '--id' flag is applicable for API versions >= 35 only.")  # noqa: E501
         client_utils.cse_restore_session(ctx)
         if client_utils.is_cli_for_tkg_s_only():
-            if k8_runtime in shared_constants.CSE_SERVER_RUNTIMES:
+            if k8_runtime in [shared_constants.ClusterEntityKind.NATIVE.value,
+                              shared_constants.ClusterEntityKind.TKG_PLUS.value]:  # noqa: E501
                 # Cannot run the command as cse cli is enabled only for native
                 raise CseServerNotRunningError()
             k8_runtime = shared_constants.ClusterEntityKind.TKG_S.value
         client = ctx.obj['client']
         cluster = Cluster(client, k8_runtime=k8_runtime)
+        # Users should be explicit in their intent about the org on which the
+        # command needs to be executed.
         if not client.is_sysadmin() and org is None:
             org = ctx.obj['profiles'].get('org_in_use')
         result = cluster.get_cluster_info(name, cluster_id=cluster_id,
@@ -993,3 +1008,292 @@ Example
     except Exception as e:
         stderr(e, ctx)
         CLIENT_LOGGER.error(str(e))
+
+
+@cluster_group.command('share',
+                       short_help='Share a cluster with at least one user')
+@click.pass_context
+@click.argument('users', nargs=-1, required=True)
+@click.option(
+    '-n',
+    '--name',
+    'name',
+    required=False,
+    default=None,
+    metavar='CLUSTER_NAME',
+    help='Name of the cluster to share')
+@click.option(
+    '--acl',
+    'acl',
+    required=True,
+    default=None,
+    metavar='ACL',
+    help=f'access control: {shared_constants.READ_ONLY}, '
+         f'{shared_constants.READ_WRITE}, or {shared_constants.FULL_CONTROL}')
+@click.option(
+    '-v',
+    '--vdc',
+    'vdc',
+    required=False,
+    default=None,
+    metavar='VDC_NAME',
+    help='Restrict cluster search to specified org VDC')
+@click.option(
+    '-o',
+    '--org',
+    'org',
+    default=None,
+    required=False,
+    metavar='ORG_NAME',
+    help='Restrict cluster search to specified org')
+@click.option(
+    '-k',
+    '--k8-runtime',
+    'k8_runtime',
+    default=None,
+    required=False,
+    metavar='K8-RUNTIME',
+    help='Restrict cluster search to cluster kind')
+@click.option(
+    '--id',
+    'cluster_id',
+    default=None,
+    required=False,
+    metavar='CLUSTER_ID',
+    help="ID of the cluster to share; "
+         "ID gets precedence over cluster name.")
+def cluster_share(ctx, name, acl, users, vdc, org, k8_runtime, cluster_id):
+    """Share cluster with users.
+
+Either the cluster name or cluster id is required.
+By default, this command searches for the cluster in the currently logged in user's org.
+
+Note: this command does not remove an ACL entry.
+
+\b
+Examples:
+    vcd cse cluster share --name mycluster --acl FullControl user1 user2
+        Share cluster 'mycluster' with FullControl access with 'user1' and 'user2'
+\b
+    vcd cse cluster share --id urn:vcloud:entity:vmware:tkgcluster:1.0.0:71fa7b01-84dc-4a58-ae54-a1098219b057 --acl ReadOnly user1
+        Share TKG-S cluster with cluster ID 'urn:vcloud:entity:vmware:tkgcluster:1.0.0:71fa7b01-84dc-4a58-ae54-a1098219b057'
+        with ReadOnly access with 'user1'
+    """  # noqa: E501
+    try:
+        # Verify access level and cluster name/id arguments
+        access_level_id = shared_constants.ACCESS_LEVEL_TYPE_TO_ID.get(acl.lower())  # noqa: E501
+        if not access_level_id:
+            raise Exception(f'Please enter a valid access control type: '
+                            f'{shared_constants.READ_ONLY}, '
+                            f'{shared_constants.READ_WRITE}, or '
+                            f'{shared_constants.FULL_CONTROL}')
+        if not (cluster_id or name):
+            raise Exception("Please specify cluster name or cluster id.")
+        client_utils.cse_restore_session(ctx)
+        if client_utils.is_cli_for_tkg_s_only():
+            if k8_runtime in [shared_constants.ClusterEntityKind.NATIVE.value,
+                              shared_constants.ClusterEntityKind.TKG_PLUS.value]:  # noqa: E501
+                # Cannot run the command as cse cli is enabled only for TKG-S
+                raise CseServerNotRunningError()
+            k8_runtime = shared_constants.ClusterEntityKind.TKG_S.value
+
+        client = ctx.obj['client']
+        # Users should be explicit in their intent about the org on which the
+        # command needs to be executed.
+        is_system_user = client.is_sysadmin()
+        if not is_system_user and org is None:
+            org = ctx.obj['profiles'].get('org_in_use')
+        elif is_system_user and org is None:
+            raise Exception("Need to specify cluster org since logged in user is in system org")  # noqa: E501
+
+        users_list = list(users)
+        cluster = Cluster(client, k8_runtime)
+        cluster.share_cluster(cluster_id, name, users_list, access_level_id,
+                              org, vdc)
+        stdout(f'Cluster {cluster_id or name} successfully shared with: {users_list}')  # noqa: E501
+    except Exception as e:
+        stderr(e, ctx)
+        CLIENT_LOGGER.error(str(e))
+
+
+@cluster_group.command('share-list',
+                       short_help='List access information of shared cluster '
+                                  'users')
+@click.pass_context
+@click.option(
+    '-A',
+    '--all',
+    'should_print_all',
+    is_flag=True,
+    default=False,
+    required=False,
+    metavar='DISPLAY_ALL',
+    help="Display all cluster user access information non-interactively")
+@click.option(
+    '-n',
+    '--name',
+    'name',
+    required=False,
+    default=None,
+    metavar='CLUSTER_NAME',
+    help='Name of the cluster to list shared users')
+@click.option(
+    '-v',
+    '--vdc',
+    'vdc',
+    required=False,
+    default=None,
+    metavar='VDC_NAME',
+    help='Restrict cluster search to specified org VDC')
+@click.option(
+    '-o',
+    '--org',
+    'org',
+    default=None,
+    required=False,
+    metavar='ORG_NAME',
+    help='Restrict cluster search to specified org')
+@click.option(
+    '-k',
+    '--k8-runtime',
+    'k8_runtime',
+    default=None,
+    required=False,
+    metavar='K8-RUNTIME',
+    help='Restrict cluster search to cluster kind')
+@click.option(
+    '--id',
+    'cluster_id',
+    default=None,
+    required=False,
+    metavar='CLUSTER_ID',
+    help="ID of the cluster whose share lists we want to retrieve; "
+         "ID gets precedence over cluster name.")
+def cluster_share_list(ctx, should_print_all, name, vdc, org, k8_runtime,
+                       cluster_id):
+    """List cluster shared user information.
+
+    Either the cluster name or cluster id is required.
+\b
+Examples:
+    vcd cse cluster share-list --name mycluster
+        List shared user information for cluster 'mycluster'
+\b
+    vcd cse cluster share --id urn:vcloud:entity:vmware:tkgcluster:1.0.0:71fa7b01-84dc-4a58-ae54-a1098219b057
+        List shared user information for cluster with cluster ID 'urn:vcloud:entity:vmware:tkgcluster:1.0.0:71fa7b01-84dc-4a58-ae54-a1098219b057'
+    """  # noqa: E501
+    try:
+        if not (cluster_id or name):
+            raise Exception("Please specify cluster name or cluster id.")
+        client_utils.cse_restore_session(ctx)
+        if client_utils.is_cli_for_tkg_s_only():
+            if k8_runtime in [shared_constants.ClusterEntityKind.NATIVE.value,
+                              shared_constants.ClusterEntityKind.TKG_PLUS.value]:  # noqa: E501
+                # Cannot run the command as cse cli is enabled only for TKG-S
+                raise CseServerNotRunningError()
+            k8_runtime = shared_constants.ClusterEntityKind.TKG_S.value
+
+        # Determine cluster type and retrieve cluster id if needed
+        client = ctx.obj['client']
+        # Users should be explicit in their intent about the org on which the
+        # command needs to be executed.
+        is_system_user = client.is_sysadmin()
+        if not is_system_user and org is None:
+            org = ctx.obj['profiles'].get('org_in_use')
+        elif is_system_user and org is None:
+            raise Exception("Need to specify cluster org since logged in user is in system org")  # noqa: E501
+
+        cluster = Cluster(client, k8_runtime)
+        share_entries = cluster.list_share_entries(cluster_id, name, org, vdc)
+        client_utils.print_paginated_result(share_entries, should_print_all)
+    except Exception as e:
+        stderr(e, ctx)
+        CLIENT_LOGGER.error(str(e))
+
+
+@cluster_group.command('unshare',
+                       short_help='Unshare a cluster with specified user(s)')
+@click.pass_context
+@click.argument('users', nargs=-1, required=True)
+@click.option(
+    '-n',
+    '--name',
+    'name',
+    required=False,
+    default=None,
+    metavar='CLUSTER_NAME',
+    help='Name of the cluster to share')
+@click.option(
+    '-v',
+    '--vdc',
+    'vdc',
+    required=False,
+    default=None,
+    metavar='VDC_NAME',
+    help='Restrict cluster search to specified org VDC')
+@click.option(
+    '-o',
+    '--org',
+    'org',
+    default=None,
+    required=False,
+    metavar='ORG_NAME',
+    help='Restrict cluster search to specified org')
+@click.option(
+    '-k',
+    '--k8-runtime',
+    'k8_runtime',
+    default=None,
+    required=False,
+    metavar='K8-RUNTIME',
+    help='Restrict cluster search to cluster kind')
+@click.option(
+    '--id',
+    'cluster_id',
+    default=None,
+    required=False,
+    metavar='CLUSTER_ID',
+    help="ID of the cluster to unshare; "
+         "ID gets precedence over cluster name.")
+def cluster_unshare(ctx, name, users, vdc, org, k8_runtime, cluster_id):
+    """Remove access from current shared cluster users.
+
+Either the cluster name or cluster id is required. By default, this command searches
+for the cluster in the currently logged in user's org.
+
+\b
+Examples:
+    vcd cse cluster unshare --name mycluster user1 user2
+        Unshare cluster 'mycluster' with FullControl access with 'user1' and 'user2'
+\b
+    vcd cse cluster unshare --id urn:vcloud:entity:vmware:tkgcluster:1.0.0:71fa7b01-84dc-4a58-ae54-a1098219b057 user1
+        Unshare TKG-S cluster with cluster ID 'urn:vcloud:entity:vmware:tkgcluster:1.0.0:71fa7b01-84dc-4a58-ae54-a1098219b057' with 'user1'
+    """  # noqa: E501
+    try:
+        if not (cluster_id or name):
+            raise Exception("Please specify cluster name or cluster id.")
+        client_utils.cse_restore_session(ctx)
+        if client_utils.is_cli_for_tkg_s_only():
+            if k8_runtime in [shared_constants.ClusterEntityKind.NATIVE.value,
+                              shared_constants.ClusterEntityKind.TKG_PLUS.value]:  # noqa: E501
+                # Cannot run the command as cse cli is enabled only for tkg
+                raise CseServerNotRunningError()
+            k8_runtime = shared_constants.ClusterEntityKind.TKG_S.value
+
+        client = ctx.obj['client']
+        # Users should be explicit in their intent about the org on which the
+        # command needs to be executed.
+        is_system_user = client.is_sysadmin()
+        if not is_system_user and org is None:
+            org = ctx.obj['profiles'].get('org_in_use')
+        elif is_system_user and org is None:
+            raise Exception("Need to specify cluster org since logged in user is in system org")  # noqa: E501
+
+        users_list = list(users)
+        cluster = Cluster(client, k8_runtime)
+        cluster.unshare_cluster(cluster_id, name, users_list, org, vdc)
+
+        stdout(f'Cluster {cluster_id or name} successfully unshared with: {users_list}')  # noqa: E501
+    except Exception as e:
+        stderr(e, ctx)
+        CLIENT_LOGGER.error(str(e))
