@@ -2,7 +2,6 @@
 # Copyright (c) 2020 VMware, Inc. All Rights Reserved.
 # SPDX-License-Identifier: BSD-2-Clause
 
-from dataclasses import asdict
 import json
 import os
 from typing import List
@@ -12,31 +11,31 @@ import yaml
 
 import container_service_extension.client.constants as cli_constants
 from container_service_extension.client.de_cluster_native import DEClusterNative  # noqa: E501
-from container_service_extension.client.de_cluster_tkg import DEClusterTKG
+from container_service_extension.client.de_cluster_tkg_s import DEClusterTKGS
 import container_service_extension.client.tkgclient.rest as tkg_rest
 import container_service_extension.client.utils as client_utils
-import container_service_extension.def_.entity_service as def_entity_svc
-import container_service_extension.def_.models as def_models
-from container_service_extension.def_.utils import DEF_VMWARE_INTERFACE_NSS
-from container_service_extension.def_.utils import DEF_VMWARE_INTERFACE_VERSION
-from container_service_extension.def_.utils import DEF_VMWARE_VENDOR
-import container_service_extension.exceptions as cse_exceptions
-import container_service_extension.logger as logger
-import container_service_extension.pyvcloud_utils as vcd_utils
-from container_service_extension.shared_constants import CSE_PAGINATION_DEFAULT_PAGE_SIZE, PaginationKey  # noqa: E501
-from container_service_extension.shared_constants import CSE_PAGINATION_FIRST_PAGE_NUMBER  # noqa: E501
+from container_service_extension.common.constants.shared_constants import CSE_PAGINATION_DEFAULT_PAGE_SIZE, PaginationKey  # noqa: E501
+from container_service_extension.common.constants.shared_constants import CSE_PAGINATION_FIRST_PAGE_NUMBER  # noqa: E501
+import container_service_extension.common.utils.pyvcloud_utils as vcd_utils
+import container_service_extension.exception.exceptions as cse_exceptions
+import container_service_extension.logging.logger as logger
+import container_service_extension.rde.common.entity_service as def_entity_svc
+from container_service_extension.rde.models.abstractNativeEntity import AbstractNativeEntity  # noqa: E501
+import container_service_extension.rde.models.common_models as common_models
+import container_service_extension.rde.schema_service as def_schema_svc
+
 
 DUPLICATE_CLUSTER_ERROR_MSG = "Duplicate clusters found. Please use --k8-runtime for the unique identification"  # noqa: E501
 
 
 class DECluster:
-    """Handle operations common to DefNative and TKG kubernetes clusters.
+    """Handle operations common to DefNative and TKG-S kubernetes clusters.
 
     Also any operation where cluster kind is not supplied should be handled here.  # noqa: E501
 
     Example(s):
         cluster list is a collection which may have mix of DefNative and
-        TKG clusters.
+        TKG-S clusters.
 
         cluster info for a given cluster name needs lookup using DEF API.
     """
@@ -45,12 +44,16 @@ class DECluster:
         logger_wire = logger.NULL_LOGGER
         if os.getenv(cli_constants.ENV_CSE_CLIENT_WIRE_LOGGING):
             logger_wire = logger.CLIENT_WIRE_LOGGER
+        self._client = client
         self._cloudapi_client = \
             vcd_utils.get_cloudapi_client_from_vcd_client(
                 client=client, logger_debug=logger.CLIENT_LOGGER,
                 logger_wire=logger_wire)
         self._nativeCluster = DEClusterNative(client)
-        self._tkgCluster = DEClusterTKG(client)
+        self._tkgCluster = DEClusterTKGS(client)
+        schema_svc = def_schema_svc.DefSchemaService(self._cloudapi_client)
+        self._server_rde_version = \
+            schema_svc.get_latest_registered_schema_version()
 
     def list_clusters(self, vdc=None, org=None, **kwargs):
         """Get collection of clusters using DEF API.
@@ -62,11 +65,10 @@ class DECluster:
         :return: cluster list information
         :rtype: list(dict)
         """
-        clusters = []
         if client_utils.is_cli_for_tkg_s_only():
             try:
                 for clusters, has_more_results in \
-                        self._tkgCluster.list_tkg_clusters(vdc=vdc, org=org):
+                        self._tkgCluster.list_tkg_s_clusters(vdc=vdc, org=org):
                     yield clusters, has_more_results
             except tkg_rest.ApiException as e:
                 if e.status not in [requests.codes.FORBIDDEN, requests.codes.UNAUTHORIZED]:  # noqa: E501
@@ -74,12 +76,13 @@ class DECluster:
                     msg = cli_constants.TKG_RESPONSE_MESSAGES_BY_STATUS_CODE.get(e.status, f"{server_message}")  # noqa: E501
                     logger.CLIENT_LOGGER.error(msg)
                     raise Exception(msg)
-                msg = f"User not authorized to fetch TKG clusters: {e}"
+                msg = f"User not authorized to fetch TKG-S clusters: {e}"
                 logger.CLIENT_LOGGER.debug(msg)
                 raise e
         else:
             # display all clusters
-            filters = client_utils.construct_filters(org=org, vdc=vdc)
+            filters = client_utils.construct_filters(
+                self._server_rde_version, org=org, vdc=vdc)
             entity_svc = def_entity_svc.DefEntityService(self._cloudapi_client)
             has_more_results = True
             page_number = CSE_PAGINATION_FIRST_PAGE_NUMBER
@@ -87,30 +90,34 @@ class DECluster:
             try:
                 while has_more_results:
                     clusters_page_results = entity_svc.get_all_entities_per_page_by_interface(  # noqa: E501
-                        vendor=DEF_VMWARE_VENDOR,
-                        nss=DEF_VMWARE_INTERFACE_NSS,
-                        version=DEF_VMWARE_INTERFACE_VERSION,
+                        vendor=common_models.K8Interface.VCD_INTERFACE.value.vendor,  # noqa: E501
+                        nss=common_models.K8Interface.VCD_INTERFACE.value.nss,
+                        version=common_models.K8Interface.VCD_INTERFACE.value.version,  # noqa: E501
                         filters=filters,
                         page_number=page_number,
                         page_size=page_size)
                     # Get the list of cluster defined entities
-                    entities: List[def_models.GenericClusterEntity] = clusters_page_results[PaginationKey.VALUES]  # noqa: E501
+                    entities: List[common_models.GenericClusterEntity] = clusters_page_results[PaginationKey.VALUES]  # noqa: E501
                     clusters = []
                     for de in entities:
                         entity = de.entity
                         logger.CLIENT_LOGGER.debug(f"Native Defined entity list from server: {entity}")  # noqa: E501
                         cluster = {
                             cli_constants.CLIOutputKey.CLUSTER_NAME.value: de.name,  # noqa: E501
-                            cli_constants.CLIOutputKey.ORG.value: de.org.name, # noqa: E501
+                            cli_constants.CLIOutputKey.ORG.value: de.org.name,  # noqa: E501
                             cli_constants.CLIOutputKey.OWNER.value: de.owner.name  # noqa: E501
                         }
-                        if type(entity) == def_models.NativeEntity:
-                            cluster[cli_constants.CLIOutputKey.VDC.value] = \
-                                entity.metadata.ovdc_name
+                        if isinstance(entity, AbstractNativeEntity):
+                            if hasattr(entity.metadata, 'ovdc_name'):
+                                cluster[cli_constants.CLIOutputKey.VDC.value] = \
+                                    entity.metadata.ovdc_name  # noqa: E501
+                            elif hasattr(entity.metadata, 'virtual_data_center_name'):  # noqa: E501
+                                cluster[cli_constants.CLIOutputKey.VDC.value] = \
+                                    entity.metadata.virtual_data_center_name  # noqa: E501
                             cluster[cli_constants.CLIOutputKey.K8S_RUNTIME.value] = entity.kind  # noqa: E501
                             cluster[cli_constants.CLIOutputKey.K8S_VERSION.value] = entity.status.kubernetes  # noqa: E501
                             cluster[cli_constants.CLIOutputKey.STATUS.value] = entity.status.phase  # noqa: E501
-                        elif type(entity) == def_models.TKGEntity:
+                        elif isinstance(entity, common_models.TKGEntity):
                             cluster[cli_constants.CLIOutputKey.VDC.value] = \
                                 entity.metadata.virtualDataCenterName
                             cluster[cli_constants.CLIOutputKey.K8S_RUNTIME.value] = entity.kind  # noqa: E501
@@ -127,22 +134,23 @@ class DECluster:
                 logger.CLIENT_LOGGER.debug(msg)
                 raise e
 
-    def _get_tkg_native_clusters_by_name(self, cluster_name: str,
-                                         org=None, vdc=None):
-        """Get native and TKG clusters by name.
+    def _get_tkg_s_and_native_clusters_by_name(self, cluster_name: str,
+                                               org=None, vdc=None):
+        """Get native and TKG-S clusters by name.
 
         Assumption: Native clusters cannot have name collision among them.
-        But there can be multiple TKG clusters with the same name and 2 or
-        more TKG clusters can also have the same name.
+        But there can be multiple TKG-S clusters with the same name and 2 or
+        more TKG-S clusters can also have the same name.
 
         :param str cluster_name: Cluster name to search for
         :param str org: Org to filter by
         :param str vdc: VDC to filter by
-        :returns: tkg-s entity or native def entity with entity properties and
+        :returns: TKG-S entity or native def entity with entity properties and
             boolean indicating cluster type
         :rtype: (cluster, dict,  bool)
         """
-        filters = client_utils.construct_filters(org=org, vdc=vdc)
+        filters = client_utils.construct_filters(
+            self._server_rde_version, org=org, vdc=vdc)
         entity_svc = def_entity_svc.DefEntityService(self._cloudapi_client)
         has_native_rights = True
         has_tkg_rights = True
@@ -151,9 +159,10 @@ class DECluster:
         # NOTE: The following can throw error if invoked by users who
         # doesn't have the necessary rights.
         try:
-            native_def_entity = entity_svc.get_native_entity_by_name(
-                name=cluster_name,
-                filters=filters)
+            native_def_entity = \
+                entity_svc.get_native_rde_by_name_and_rde_version(
+                    cluster_name, self._server_rde_version,
+                    filters=filters)
         except cse_exceptions.DefSchemaServiceError:
             # NOTE: 500 status code is returned which is not ideal
             # when user doesn't have native rights
@@ -165,14 +174,14 @@ class DECluster:
         # doesn't have the necessary rights.
         try:
             tkg_entity, tkg_def_entity = \
-                self._tkgCluster.get_tkg_clusters_by_name(cluster_name,
-                                                          vdc=vdc, org=org)
+                self._tkgCluster.get_tkg_s_clusters_by_name(cluster_name,
+                                                            vdc=vdc, org=org)
         except tkg_rest.ApiException as e:
             if e.status not in [requests.codes.FORBIDDEN, requests.codes.UNAUTHORIZED]:  # noqa: E501
                 raise
             has_tkg_rights = False
         except cse_exceptions.ClusterNotFoundError:
-            logger.CLIENT_LOGGER.debug(f"No TKG cluster with name {cluster_name}")  # noqa: E501
+            logger.CLIENT_LOGGER.debug(f"No TKG-S cluster with name {cluster_name}")  # noqa: E501
         if not (has_native_rights or has_tkg_rights):
             raise Exception("User cannot access native or TKG clusters."
                             " Please contact administrator")
@@ -181,11 +190,11 @@ class DECluster:
             # If org filter is not provided, ask the user to provide org
             # filter
             if not org:
-                # handles the case where there is are TKG clusters and native
+                # handles the case where there are TKG-S clusters and native
                 # clusters with the same name in different organizations
                 raise Exception(f"{msg} Please specify the org to use "
                                 "using --org flag.")
-            # handles the case where there is a TKG cluster and a native
+            # handles the case where there is a TKG-S cluster and a native
             # native cluster with the same name in the same organization
             raise Exception(f"{msg} Please specify the k8-runtime to use using"
                             " --k8-runtime flag.")
@@ -209,8 +218,9 @@ class DECluster:
         """Get cluster information using DEF API.
 
         :param str cluster_name: name of the cluster
-        :param str vdc: name of vdc
+        :param str cluster_id:
         :param str org: name of org
+        :param str vdc: name of vdc
         :param kwargs: *filter (dict): keys,values for DEF API query filter
 
         :return: cluster information
@@ -222,12 +232,12 @@ class DECluster:
         if cluster_id:
             return self.get_cluster_info_by_id(cluster_id, org=org)
         cluster, _, is_native_cluster = \
-            self._get_tkg_native_clusters_by_name(cluster_name,
-                                                  org=org, vdc=vdc)
+            self._get_tkg_s_and_native_clusters_by_name(cluster_name,
+                                                        org=org, vdc=vdc)
         if is_native_cluster:
-            cluster_info = asdict(cluster.entity)
+            cluster_info = cluster.entity.to_dict()
         else:
-            # TKG cluster represents the defined_entity.entity
+            # TKG-S cluster represents the defined_entity.entity
             cluster_info = client_utils.swagger_object_to_dict(cluster)
         logger.CLIENT_LOGGER.debug(
             f"Received defined entity of cluster {cluster_name} : {cluster_info}")  # noqa: E501
@@ -236,7 +246,9 @@ class DECluster:
     def get_cluster_info_by_id(self, cluster_id, org=None):
         """Obtain cluster information using cluster ID.
 
-        :param str cluster_id
+        :param str cluster_id:
+        :param str org:
+
         :return: yaml representation of the cluster information
         :rtype: str
         """
@@ -250,8 +262,10 @@ class DECluster:
         """Get cluster config.
 
         :param str cluster_name: name of the cluster
-        :param str vdc: name of vdc
+        :param str cluster_id:
         :param str org: name of org
+        :param str vdc: name of vdc
+
 
         :return: cluster information
         :rtype: str
@@ -260,8 +274,8 @@ class DECluster:
         if cluster_id:
             return self.get_cluster_config_by_id(cluster_id, org=org)
         cluster, entity_properties, is_native_cluster = \
-            self._get_tkg_native_clusters_by_name(cluster_name,
-                                                  org=org, vdc=vdc)
+            self._get_tkg_s_and_native_clusters_by_name(cluster_name,
+                                                        org=org, vdc=vdc)
         if is_native_cluster:
             return self._nativeCluster.get_cluster_config_by_id(cluster.id)
         return self._tkgCluster.get_cluster_config_by_id(cluster_id=entity_properties.get('id'))  # noqa: E501
@@ -282,8 +296,10 @@ class DECluster:
         """Delete DEF cluster by name.
 
         :param str cluster_name: name of the cluster
+        :param str cluster_id:
         :param str org: name of the org
         :param str vdc: name of the vdc
+
         :return: deleted cluster info
         :rtype: str
         :raises ClusterNotFoundError, CseDuplicateClusterError
@@ -291,8 +307,8 @@ class DECluster:
         if cluster_id:
             return self.delete_cluster_by_id(cluster_id)
         cluster, entity_properties, is_native_cluster = \
-            self._get_tkg_native_clusters_by_name(cluster_name,
-                                                  org=org, vdc=vdc)
+            self._get_tkg_s_and_native_clusters_by_name(cluster_name,
+                                                        org=org, vdc=vdc)
         if is_native_cluster:
             return self._nativeCluster.delete_cluster_by_id(cluster.id)
         return self._tkgCluster.delete_cluster_by_id(cluster_id=entity_properties.get('id'))  # noqa: E501
@@ -301,8 +317,11 @@ class DECluster:
         """Delete cluster using cluster id.
 
         :param str cluster_id: id of the cluster to be deleted
+        :param str org:
+
         :return: deleted cluster information
         :rtype: str
+
         :raises: ClusterNotFoundError
         """
         entity_svc = def_entity_svc.DefEntityService(self._cloudapi_client)
@@ -321,7 +340,7 @@ class DECluster:
         :raises ClusterNotFoundError, CseDuplicateClusterError
         """
         cluster, _, is_native_cluster = \
-            self._get_tkg_native_clusters_by_name(cluster_name, org=org, vdc=vdc)  # noqa: E501
+            self._get_tkg_s_and_native_clusters_by_name(cluster_name, org=org, vdc=vdc)  # noqa: E501
         if is_native_cluster:
             return self._nativeCluster.get_upgrade_plan_by_cluster_id(cluster.id)  # noqa: E501
         self._tkgCluster.get_upgrade_plan(cluster_name, vdc=vdc, org=org)
@@ -341,10 +360,65 @@ class DECluster:
         :rtype: str
         """
         cluster, _, is_native_cluster = \
-            self._get_tkg_native_clusters_by_name(cluster_name, org=org_name, vdc=ovdc_name)  # noqa: E501
+            self._get_tkg_s_and_native_clusters_by_name(cluster_name, org=org_name, vdc=ovdc_name)  # noqa: E501
         if is_native_cluster:
             cluster.entity.spec.k8_distribution.template_name = template_name
             cluster.entity.spec.k8_distribution.template_revision = template_revision  # noqa: E501
-            cluster_dict = asdict(cluster)
+            cluster_dict = cluster.to_dict()
             return self._nativeCluster.upgrade_cluster_by_cluster_id(cluster.id, cluster_def_entity=cluster_dict)  # noqa: E501
         self._tkgCluster.upgrade_cluster(cluster_name, template_name, template_revision)  # noqa: E501
+
+    def share_cluster(self, cluster_id, cluster_name, users: list,
+                      access_level_id, org=None, vdc=None):
+        # Find cluster type
+        if cluster_id:
+            entity_svc = def_entity_svc.DefEntityService(self._cloudapi_client)
+            is_native_cluster = entity_svc.is_native_entity(cluster_id)
+        else:
+            _, _, is_native_cluster = \
+                self._get_tkg_s_and_native_clusters_by_name(
+                    cluster_name, org=org, vdc=vdc
+                )
+
+        if is_native_cluster:
+            self._nativeCluster.share_cluster(cluster_id, cluster_name, users,
+                                              access_level_id, org, vdc)
+        else:
+            self._tkgCluster.share_cluster(cluster_id, cluster_name, users,
+                                           access_level_id, org, vdc)
+
+    def list_share_entries(self, cluster_id, cluster_name, org=None, vdc=None):
+        # Find cluster type
+        if cluster_id:
+            entity_svc = def_entity_svc.DefEntityService(self._cloudapi_client)
+            is_native_cluster = entity_svc.is_native_entity(cluster_id)
+        else:
+            _, _, is_native_cluster = \
+                self._get_tkg_s_and_native_clusters_by_name(
+                    cluster_name, org=org, vdc=vdc
+                )
+
+        if is_native_cluster:
+            return self._nativeCluster.list_share_entries(
+                cluster_id, cluster_name, org, vdc)
+        else:
+            return self._tkgCluster.list_share_entries(
+                cluster_id, cluster_name, org, vdc)
+
+    def unshare_cluster(self, cluster_id, cluster_name, users: list, org=None,
+                        vdc=None):
+        if cluster_id:
+            entity_svc = def_entity_svc.DefEntityService(self._cloudapi_client)
+            is_native_cluster = entity_svc.is_native_entity(cluster_id)
+        else:
+            _, _, is_native_cluster = \
+                self._get_tkg_s_and_native_clusters_by_name(
+                    cluster_name, org=org, vdc=vdc
+                )
+
+        if is_native_cluster:
+            self._nativeCluster.unshare_cluster(cluster_id, cluster_name,
+                                                users, org, vdc)
+        else:
+            self._tkgCluster.unshare_cluster(cluster_id, cluster_name, users,
+                                             org, vdc)
