@@ -10,9 +10,9 @@ import container_service_extension.client.command_filter as cmd_filter
 import container_service_extension.client.constants as cli_constants
 from container_service_extension.client.ovdc import Ovdc
 import container_service_extension.client.utils as client_utils
-from container_service_extension.logger import CLIENT_LOGGER
-import container_service_extension.shared_constants as shared_constants
-import container_service_extension.utils as utils
+import container_service_extension.common.constants.shared_constants as shared_constants  # noqa: E501
+import container_service_extension.common.utils.core_utils as utils
+from container_service_extension.logging.logger import CLIENT_LOGGER
 
 
 @click.group(name='ovdc', cls=cmd_filter.GroupCommandFilter,
@@ -93,16 +93,7 @@ Example
     hidden=not utils.is_environment_variable_enabled(cli_constants.ENV_CSE_TKG_PLUS_ENABLED),  # noqa: E501
     help="Enable OVDC for k8 runtime TKG plus"
 )
-@click.option(
-    '-t',
-    '--tkg',
-    'enable_tkg_m',
-    is_flag=True,
-    hidden=not utils.is_environment_variable_enabled(cli_constants.ENV_CSE_TKG_M_ENABLED),  # noqa: E501
-    help="Enable OVDC for k8 runtime TKGm"
-)
-def ovdc_enable(ctx, ovdc_name, org_name, enable_native, enable_tkg_plus=None,
-                enable_tkg_m=None):
+def ovdc_enable(ctx, ovdc_name, org_name, enable_native, enable_tkg_plus=None):
     """Set Kubernetes provider for an org VDC.
 
 \b
@@ -116,7 +107,7 @@ Example
         Supported only for vcd api version < 35.
     """
     CLIENT_LOGGER.debug(f'Executing command: {ctx.command_path}')
-    if not (enable_native or enable_tkg_plus or enable_tkg_m):
+    if not (enable_native or enable_tkg_plus):
         msg = "Please specify at least one k8 runtime to enable"
         stderr(msg, ctx)
         CLIENT_LOGGER.error(msg)
@@ -125,8 +116,6 @@ Example
         k8_runtime.append(shared_constants.ClusterEntityKind.NATIVE.value)
     if enable_tkg_plus:
         k8_runtime.append(shared_constants.ClusterEntityKind.TKG_PLUS.value)
-    if enable_tkg_m:
-        k8_runtime.append(shared_constants.ClusterEntityKind.TKG_M.value)
     try:
         client_utils.cse_restore_session(ctx)
         client = ctx.obj['client']
@@ -178,14 +167,6 @@ Example
     hidden=not utils.is_environment_variable_enabled(cli_constants.ENV_CSE_TKG_PLUS_ENABLED),  # noqa: E501
     help="Disable OVDC for k8 runtime TKG plus"
 )
-@click.option(
-    '-t',
-    '--tkg',
-    'disable_tkg_m',
-    is_flag=True,
-    hidden=not utils.is_environment_variable_enabled(cli_constants.ENV_CSE_TKG_M_ENABLED),  # noqa: E501
-    help="Disable OVDC for k8 runtime TKGm"
-)
 @click.option(
     '-f',
     '--force',
@@ -194,7 +175,7 @@ Example
     help="Remove the compute policies from deployed VMs as well. "
          "Does not remove the compute policy from vApp templates in catalog. ")
 def ovdc_disable(ctx, ovdc_name, org_name,
-                 disable_native, disable_tkg_plus=None, disable_tkg_m=None,
+                 disable_native, disable_tkg_plus=None,
                  remove_cp_from_vms_on_disable=False):
     """Disable Kubernetes cluster deployment for an org VDC.
 
@@ -215,7 +196,7 @@ Examples
 
     """
     CLIENT_LOGGER.debug(f'Executing command: {ctx.command_path}')
-    if not (disable_native or disable_tkg_plus or disable_tkg_m):
+    if not (disable_native or disable_tkg_plus):
         msg = "Please specify at least one k8 runtime to disable"
         stderr(msg, ctx)
         CLIENT_LOGGER.error(msg)
@@ -224,8 +205,6 @@ Examples
         k8_runtime.append(shared_constants.ClusterEntityKind.NATIVE.value)
     if disable_tkg_plus:
         k8_runtime.append(shared_constants.ClusterEntityKind.TKG_PLUS.value)
-    if disable_tkg_m:
-        k8_runtime.append(shared_constants.ClusterEntityKind.TKG_M.value)
     try:
         client_utils.cse_restore_session(ctx)
         client = ctx.obj['client']
@@ -237,7 +216,7 @@ Examples
                                       ovdc_name=ovdc_name,
                                       org_name=org_name,
                                       k8s_runtime=k8_runtime,
-                                      remove_cp_from_vms_on_disable=remove_cp_from_vms_on_disable) # noqa: E501
+                                      remove_cp_from_vms_on_disable=remove_cp_from_vms_on_disable)  # noqa: E501
             stdout(result, ctx)
             CLIENT_LOGGER.debug(result)
         else:
@@ -309,7 +288,7 @@ Examples
 \b
     vcd cse ovdc compute-policy remove POLICY_NAME --org ORG_NAME --vdc VDC_NAME
         Remove a compute policy from a specific ovdc in a specific org.
-    """ # noqa: E501
+    """  # noqa: E501
     pass
 
 
@@ -375,7 +354,7 @@ def compute_policy_add(ctx, org_name, ovdc_name, compute_policy_name):
         result = ovdc.update_ovdc_compute_policies(ovdc_name,
                                                    org_name,
                                                    compute_policy_name,
-                                                   shared_constants.ComputePolicyAction.ADD, # noqa: E501
+                                                   shared_constants.ComputePolicyAction.ADD,  # noqa: E501
                                                    False)
         stdout(result, ctx)
         CLIENT_LOGGER.debug(result)
@@ -420,11 +399,12 @@ def compute_policy_remove(ctx, org_name, ovdc_name, compute_policy_name,
             raise Exception("Insufficient permission to perform operation.")
 
         ovdc = Ovdc(client)
-        result = ovdc.update_ovdc_compute_policies(ovdc_name,
-                                                   org_name,
-                                                   compute_policy_name,
-                                                   shared_constants.ComputePolicyAction.REMOVE, # noqa: E501
-                                                   remove_compute_policy_from_vms) # noqa: E501
+        result = ovdc.update_ovdc_compute_policies(
+            ovdc_name,
+            org_name,
+            compute_policy_name,
+            shared_constants.ComputePolicyAction.REMOVE,
+            remove_compute_policy_from_vms)
         stdout(result, ctx)
         CLIENT_LOGGER.debug(result)
     except Exception as e:
