@@ -1,14 +1,12 @@
 # container-service-extension
 # Copyright (c) 2020 VMware, Inc. All Rights Reserved.
 # SPDX-License-Identifier: BSD-2-Clause
-import dataclasses
 
 import yaml
 
-import container_service_extension.def_.models as def_models
-from container_service_extension.logger import CLIENT_LOGGER
-import container_service_extension.shared_constants as shared_constants
-
+import container_service_extension.common.constants.shared_constants as shared_constants  # noqa: E501
+from container_service_extension.logging.logger import CLIENT_LOGGER
+import container_service_extension.rde.models.rde_factory as rde_factory
 
 SAMPLE_K8_CLUSTER_SPEC_HELP = """# Short description of various properties used in this sample cluster configuration
 # kind: The kind of the Kubernetes cluster.
@@ -71,18 +69,22 @@ SAMPLE_TKG_CLUSTER_SPEC_HELP = """# Short description of various properties used
 """  # noqa: E501
 
 
-def get_sample_cluster_configuration(output=None, k8_runtime=None):
+def get_sample_cluster_configuration(output=None, k8_runtime=None, server_rde_in_use=None):  # noqa: E501
     """Generate sample cluster configuration.
 
     :param str output: full path of output file
     :param shared_constants.ClusterEntityKind k8_runtime: cluster kind
+    :param str server_rde_in_use:
+
     :return: sample cluster configuration
     :rtype: str
     """
-    if k8_runtime == shared_constants.ClusterEntityKind.TKG_S.value:
+    if k8_runtime == shared_constants.ClusterEntityKind.TKG_S:
         sample_cluster_config = SAMPLE_TKG_CLUSTER_SPEC_HELP + _get_sample_tkg_cluster_configuration()  # noqa: E501
     else:
-        sample_cluster_config = SAMPLE_K8_CLUSTER_SPEC_HELP + _get_sample_cluster_configuration_by_k8_runtime(k8_runtime)  # noqa: E501
+        if not server_rde_in_use:
+            raise ValueError("CSE server API version required to generate sample config")  # noqa: E501
+        sample_cluster_config = _get_sample_cluster_configuration_by_k8_runtime(k8_runtime, server_rde_in_use)  # noqa: E501
 
     if output:
         with open(output, 'w') as f:
@@ -91,49 +93,9 @@ def get_sample_cluster_configuration(output=None, k8_runtime=None):
     return sample_cluster_config
 
 
-def _get_sample_cluster_configuration_by_k8_runtime(k8_runtime):
-    metadata = def_models.Metadata('cluster_name', 'organization_name',
-                                   'org_virtual_datacenter_name')
-    status = def_models.Status()
-    settings = def_models.Settings(network='ovdc_network_name', ssh_key=None)
-    k8_distribution = def_models.Distribution(
-        template_name='ubuntu-16.04_k8-1.17_weave-2.6.0',
-        template_revision=2
-    )
-    control_plane = def_models.ControlPlane(
-        count=1,
-        sizing_class='Large_sizing_policy_name',
-        storage_profile='Gold_storage_profile_name'
-    )
-    workers = def_models.Workers(
-        count=2,
-        sizing_class='Medium_sizing_policy_name',
-        storage_profile='Silver_storage_profile'
-    )
-
-    nfs = def_models.Nfs(
-        count=0,
-        sizing_class='Large_sizing_policy_name',
-        storage_profile='Platinum_storage_profile_name'
-    )
-
-    cluster_spec = def_models.ClusterSpec(
-        control_plane=control_plane,
-        k8_distribution=k8_distribution,
-        settings=settings,
-        workers=workers,
-        nfs=nfs
-    )
-    cluster_entity = def_models.NativeEntity(
-        metadata=metadata,
-        spec=cluster_spec,
-        status=status,
-        kind=k8_runtime
-    )
-
-    sample_cluster_config = yaml.dump(dataclasses.asdict(cluster_entity))
-    CLIENT_LOGGER.info(sample_cluster_config)
-    return sample_cluster_config
+def _get_sample_cluster_configuration_by_k8_runtime(k8_runtime, server_rde_in_use):  # noqa: E501
+    NativeEntityClass = rde_factory.get_rde_model(server_rde_in_use)
+    return NativeEntityClass.get_sample_native_cluster_specification(k8_runtime)  # noqa: E501
 
 
 def _get_sample_tkg_cluster_configuration():
@@ -159,9 +121,9 @@ def _get_sample_tkg_cluster_configuration():
         "metadata": {
             "name": "cluster_name",
             "placementPolicy": "placement_policy_name",
-            "virtualDataCenterName": "org_virtual_datacenter_name"
+            "virtualDataCenterName": "org_virtual_data_center_name"
         }
     }
-    sample_cluster_config = yaml.dump(sample_tkg_plus_config)
-    CLIENT_LOGGER.info(sample_cluster_config)
-    return sample_cluster_config
+    sample_apply_spec = yaml.dump(sample_tkg_plus_config)
+    CLIENT_LOGGER.info(sample_apply_spec)
+    return sample_apply_spec
